
#import "T1PDFView.h"

@implementation T1PDFView

+ (instancetype)pdfViewWithPDF:(CGPDFDocumentRef)pdf frame:(CGRect)frame {
	T1PDFView *pdfView = [[self alloc] initWithFrame:frame];
	pdfView.pdf = pdf;
	return pdfView;
}

- (id)initWithFrame:(CGRect)frame {
	if (self = [super initWithFrame:frame]) {
		self.opaque = NO;
	}
	return self;
}

- (void)setPdf:(CGPDFDocumentRef)pdf {
	CGPDFDocumentRelease(_pdf);
	CGPDFDocumentRetain(pdf);
	_pdf = pdf;
}

- (void)drawRect:(CGRect)rect
{
	CGContextRef ctx = UIGraphicsGetCurrentContext();
 
	// Optionally set a background color
	if (self.backgroundColor) {
		[self.backgroundColor set];
		CGContextFillRect(ctx, rect);
	}
 
	// Flip coordinates
	CGContextGetCTM(ctx);
	CGContextScaleCTM(ctx, 1, -1);
	CGContextTranslateCTM(ctx, 0, -rect.size.height);
 
	if (self.pdf == nil) {
		return;
	}
	CGPDFPageRef page1 = CGPDFDocumentGetPage(self.pdf, 1);
 
	// get the rectangle of the cropped inside
	CGRect mediaRect = CGPDFPageGetBoxRect(page1, kCGPDFCropBox);
	CGContextScaleCTM(ctx, rect.size.width / mediaRect.size.width,
					  rect.size.height / mediaRect.size.height);
	CGContextTranslateCTM(ctx, -mediaRect.origin.x, -mediaRect.origin.y);
 
	// draw it
	CGContextDrawPDFPage(ctx, page1);
}

- (void)dealloc {
	CGPDFDocumentRelease(self.pdf);
}

@end
