

#import "ViewController.h"
#import "T1PDFView.h"

@interface ViewController ()

@property (strong) T1Autograph *autograph;
@property (strong) T1Autograph *autographModal;
@property (weak, nonatomic) IBOutlet UIImageView *outputImage;
@property (weak, nonatomic) IBOutlet UIView *autographView;

@end

@implementation ViewController

#pragma mark - View Loading and Configuration Methods


- (void)viewDidLoad {
	
	[super viewDidLoad];
	
	// Initialize Autograph library
	self.autograph = [T1Autograph autographWithView:self.autographView delegate:self];
	
	// to remove the watermark, get a license code from Ten One, and enter it here
	self.autograph.licenseCode = @"a9668f950eb2a30109ab1666bcc9cf885337095f";
	
	
#pragma mark - ** START OF Optional Configuration **
	
	// Clips signature UIImage to the bounds of the signature capture UIView.  Default is NO
	//	self.autograph.clipSignatureToBounds = YES;
	
	// show signature guideline.  Default is YES
	//	self.autograph.showGuideline = NO;
	
	// set export color.  Default is blackColor
	//	self.autograph.strokeColor = [UIColor darkGrayColor];
	
	// set stroke width.  Default is 6
	//	self.autograph.strokeWidth = 3;
	
	// set amount of stroke width reduction from velocity.  Default is 0.85
	//	self.autograph.velocityReduction = 0.5;
	
	// set export size.  Default scale is 1.0
	//	self.autograph.exportScale = 0.5f;
	
	// show current date.  Default is NO
	//	self.autograph.showDate = YES;
	
	// add current time to signature.  Requires showDate == YES.  Default is NO
	//	self.autograph.dateIncludesTime = YES;
	
	// show unique signature identifier.  Default is NO
	//	self.autograph.showHash = YES;
	
	// customize signature identifier.  Default is nil.  Use no more than 10 characters.
	//	self.autograph.customHash = @"DocumentID";
	
	// enable 3-finger swipe to undo.  Default is YES
	//	self.autograph.swipeToUndoEnabled = NO;
	
	
	NSLog(@"Autograph SDK build number %d", (int)self.autograph.buildNumber);

}

#pragma mark - UI Button Methods



- (IBAction)clearButtonAction:(id)sender {
	[self.autograph reset:self];
}

- (IBAction)doneButtonAction:(id)sender {
	[self.autograph done:self];
	[self.autograph reset:self];
}

- (IBAction)showModalButtonAction:(id)sender {
	// Show modal view with a message above the signature line
	self.autographModal = [T1Autograph autographWithDelegate:self modalDisplayString:@"I hereby authorize the biogenetic payload scheduled for the April 7 launch."];
	
	// Show modal view without a message above the signature line
	//	self.autographModal = [T1Autograph autographWithDelegate:self modalDisplayString:nil];
	
	// Remove the watermark
	self.autographModal.licenseCode = @"a9668f950eb2a30109ab1666bcc9cf885337095f";
	
	// any optional configuration done here
	self.autographModal.strokeColor = [UIColor darkGrayColor];
}

#pragma mark - T1Autograph Delegate Methods


- (void)autographDidCancelModalView:(T1Autograph *)autograph {
	NSLog(@"Autograph modal signature has been cancelled");
}

- (void)autographDidCompleteWithNoSignature:(T1Autograph *)autograph {
	NSLog(@"User pressed the done button without signing");
}

- (void)autograph:(T1Autograph *)autograph didEndLineWithSignaturePointCount:(NSUInteger)count {
	NSLog(@"Line ended with total signature point count of %d", (int)count);
	
	// Note: You can use the 'count' parameter to determine if the line is substantial enough to enable the done or clear button.
}

- (void)autograph:(T1Autograph *)autograph willCompleteWithSignature:(T1Signature *)signature {
	NSLog(@"Autograph will complete with signature");
}

- (void)autograph:(T1Autograph *)autograph didCompleteWithSignature:(T1Signature *)signature {
	// Log information about the signature
	NSLog(@"-- Autograph signature completed. --");
	
	// display the signature
	self.outputImage.image = signature.imageView.image;
	
	// You can access the raw image data like this:
	// UIImage *img = [UIImage imageWithData:signature.imageData];
	
	// You can access the raw data points like this:
	// NSArray *rawPoints = signature.rawPoints;
	
	// You can use the PDF format to scale to any size like this:
//		float scaleValue = 1.8;
//		CGRect pdfFrame = CGRectMake(self.view.frame.size.width / 15, 270, signature.frame.size.width * scaleValue, signature.frame.size.height * scaleValue);
//		T1PDFView *pdfView = [T1PDFView pdfViewWithPDF:signature.pdf frame:pdfFrame];
//		[self.view addSubview:pdfView];
	
//	NSLog(@"rawPoints: %@",signature.rawPoints);
//	NSLog(@"xml: %@",signature.xmlString);
}


@end
